package com.sun.media.sound;

import javax.sound.midi.MidiDevice;

public final class MidiOutDeviceProvider extends AbstractMidiDeviceProvider
{
    private static AbstractMidiDeviceProvider.Info[] infos;
    private static MidiDevice[] devices;
    private static final boolean enabled;
    
    public MidiOutDeviceProvider() {
    }
    
    @Override
    AbstractMidiDeviceProvider.Info createInfo(int n) {
        if (!MidiOutDeviceProvider.enabled) {
            return null;
        }
        return new MidiOutDeviceProvider.MidiOutDeviceInfo(n, MidiOutDeviceProvider.class);
    }
    
    @Override
    MidiDevice createDevice(AbstractMidiDeviceProvider.Info info) {
        if (MidiOutDeviceProvider.enabled && info instanceof MidiOutDeviceProvider.MidiOutDeviceInfo) {
            return new MidiOutDevice(info);
        }
        return null;
    }
    
    @Override
    int getNumDevices() {
        if (!MidiOutDeviceProvider.enabled) {
            return 0;
        }
        return nGetNumDevices();
    }
    
    @Override
    MidiDevice[] getDeviceCache() {
        return MidiOutDeviceProvider.devices;
    }
    
    @Override
    void setDeviceCache(MidiDevice[] devices) {
        MidiOutDeviceProvider.devices = devices;
    }
    
    @Override
    AbstractMidiDeviceProvider.Info[] getInfoCache() {
        return MidiOutDeviceProvider.infos;
    }
    
    @Override
    void setInfoCache(AbstractMidiDeviceProvider.Info[] infos) {
        MidiOutDeviceProvider.infos = infos;
    }
    
    private static native int nGetNumDevices();
    
    private static native String nGetName(int p0);
    
    private static native String nGetVendor(int p0);
    
    private static native String nGetDescription(int p0);
    
    private static native String nGetVersion(int p0);
    
    static String access$100(int n) {
        return nGetName(n);
    }
    
    static String access$200(int n) {
        return nGetVendor(n);
    }
    
    static String access$300(int n) {
        return nGetDescription(n);
    }
    
    static String access$400(int n) {
        return nGetVersion(n);
    }
    
    static {
        MidiOutDeviceProvider.infos = null;
        MidiOutDeviceProvider.devices = null;
        Platform.initialize();
        enabled = Platform.isMidiIOEnabled();
    }
    
    static final class MidiOutDeviceInfo extends AbstractMidiDeviceProvider.Info
    {
        private final Class providerClass;
        
        private MidiOutDeviceInfo(int n, Class providerClass) {
            super(MidiOutDeviceProvider.access$100(n), MidiOutDeviceProvider.access$200(n), MidiOutDeviceProvider.access$300(n), MidiOutDeviceProvider.access$400(n), n);
            this.providerClass = providerClass;
        }
    }
}
